---
title: <span class="badge builder"></span> DashboardFieldConfigSourceOverrides
---
# <span class="badge builder"></span> DashboardFieldConfigSourceOverrides

## Constructor

```python
DashboardFieldConfigSourceOverrides()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> dashboard.DashboardFieldConfigSourceOverrides
```

### <span class="badge object-method"></span> matcher

```python
def matcher(matcher: dashboard.MatcherConfig) -> typing.Self
```

### <span class="badge object-method"></span> properties

```python
def properties(properties: list[dashboard.DynamicConfigValue]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [DashboardFieldConfigSourceOverrides](./object-DashboardFieldConfigSourceOverrides.md)
